public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2016-04-15 15:52 Michael Palimaka
  0 siblings, 0 replies; 13+ messages in thread
From: Michael Palimaka @ 2016-04-15 15:52 UTC (permalink / raw
  To: gentoo-commits

commit:     c299b7fa37c8975b893ed32d36ee981d3f87d58b
Author:     Michael Palimaka <kensington <AT> gentoo <DOT> org>
AuthorDate: Fri Apr 15 15:51:49 2016 +0000
Commit:     Michael Palimaka <kensington <AT> gentoo <DOT> org>
CommitDate: Fri Apr 15 15:52:37 2016 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=c299b7fa

Documentation: add new one-stop script to bump frameworks

 Documentation/maintainers/new/frameworks-bump.sh |  52 +++++++++
 Documentation/maintainers/new/lib.sh             | 131 ++++++++++++++++++++++-
 2 files changed, 178 insertions(+), 5 deletions(-)

diff --git a/Documentation/maintainers/new/frameworks-bump.sh b/Documentation/maintainers/new/frameworks-bump.sh
new file mode 100755
index 0000000..f727391
--- /dev/null
+++ b/Documentation/maintainers/new/frameworks-bump.sh
@@ -0,0 +1,52 @@
+#!/bin/sh
+. "$(dirname "$0")/lib.sh"
+
+: ${TARGET_REPO:="$(pwd)"}
+
+help() {
+	echo "Perform a version bump of KDE Frameworks."
+	echo
+	echo "Based on the kde-frameworks-live set, this script performs a full version bump"
+	echo "of a new unreleased KDE Frameworks."
+	echo
+	echo "In addition to the new ebuild being created, the following operations are performed:"
+	echo
+	echo "* Creation of versioned set"
+	echo "* Creation of package.mask entry"
+	echo "* Eclass modification to mark as unreleased"
+	echo "* Generation of package.* files in Documentation"
+	echo
+	echo "Usage: frameworks-bump.sh <version>"
+	echo "Example: frameworks-bump.sh 5.30"
+	exit 0
+}
+
+if [[ $1 == "--help" ]] ; then
+	help
+fi
+
+VERSION="${1}"
+
+if [[ -z "${VERSION}" ]] ; then
+	echo ERROR: Not enough arguments
+	echo
+	help
+fi
+
+major_version=$(echo ${VERSION} | cut -d "." -f 1-2)
+kfv="kde-frameworks-${VERSION}"
+kfmv="kde-frameworks-${major_version}"
+
+pushd "${TARGET_REPO}" > /dev/null
+
+bump_set_from_live kde-frameworks ${major_version}
+mask_from_live_set kde-frameworks ${VERSION} ${kfv}
+mark_unreleased ${kfv}
+create_keywords_files kde-frameworks-live ${kfmv}
+
+sed -i -e "/KF_RELEASES/s/\"$/ ${major_version}\"/" Documentation/maintainers/regenerate-files
+Documentation/maintainers/regenerate-files
+
+bump_packages_from_set kde-frameworks-live 9999 ${VERSION}
+
+popd > /dev/null

diff --git a/Documentation/maintainers/new/lib.sh b/Documentation/maintainers/new/lib.sh
index b336399..9bd9d1f 100755
--- a/Documentation/maintainers/new/lib.sh
+++ b/Documentation/maintainers/new/lib.sh
@@ -3,19 +3,140 @@
 # requires app-portage/portage-utils and app-portage/gentoolkit-dev
 
 : ${SOURCE_REPO:="$(realpath $(dirname $0)/../../../)"}
-: ${TARGET_REPO:="$(pwd)"}
 
-get_package_list_from_set() {
-	local set="${1}"
+# @FUNCTION: bump_packages_from_set
+# @USAGE: <set name> <source version> <target version>
+# @DESCRIPTION:
+# Using packages listed in <set name>, bump new <target version> ebuilds based on
+# <source version>
+bump_packages_from_set() {
+	local setname="${1}"
+	local sourceversion="${2}"
+	local targetversion="${3}"
 
-	for entry in $(grep -v ^[#@] "${SOURCE_REPO}/sets/${set}") ; do
-		echo $(qatom ${entry} | cut -d " " -f 1-2 | tr " " "/")
+	local packages=$(get_package_list_from_set ${setname})
+
+	for cp in ${packages} ; do
+		trap "echo Exited without finishing!; exit;" SIGINT SIGTERM
+		pushd "${cp}" > /dev/null
+
+		local pn=$(basename $(pwd))
+		local source=${pn}-${sourceversion}.ebuild
+		local destination=${pn}-${targetversion}.ebuild
+
+		cp ${source} ${destination}
+		ekeyword ^all ${destination} > /dev/null
+
+		if [[ ${destination} != *9999* ]] ; then
+			ekeyword $(get_main_tree_keyword ${cp}) ${destination} > /dev/null
+		fi
+
+		repoman manifest
+
+        	popd > /dev/null
 	done
 }
 
+# @FUNCTION: bump_set_from_live
+# @USAGE: <base set name> <new version>
+# @DESCRIPTION:
+# Creates new set <base setname>-<new version> based on <base setname>-live.
+bump_set_from_live() {
+	local target="${1}"
+	local destination="${2}"
+
+	cp sets/${target}-live sets/${target}-${destination}
+	sed -i -e "s/~/</" -e "s/9999/${VERSION}/" -e "s/0/50:5/" sets/${target}-${destination}
+
+}
+
+# @FUNCTION: bump_set_from_live
+# @USAGE: <base set name> <new version>
+# @DESCRIPTION:
+# Creates new set <base setname>-<new version> based on <base setname>-live.
+create_keywords_files() {
+	local setname="${1}"
+	local target="${2}"
+
+	pushd Documentation > /dev/null
+	pushd package.unmask > /dev/null
+	cp -r .${setname} .${target}
+	pushd .${target} > /dev/null
+	rm ${setname}
+	ln -s  ../../../sets/${target} ${target}
+	echo "# You can use this file to mask/unmask the $(pretty_setname ${target}) release." > _HEADER_
+	echo "# Edit Documentation/package.unmask/.${target}/ files instead." >> _HEADER_
+	popd > /dev/null
+	popd > /dev/null
+
+	pushd package.accept_keywords > /dev/null
+	cp -r .${setname}.base .${target}
+	pushd .${target} > /dev/null
+	rm ${setname}
+	ln -s  ../../../sets/${target} ${target}
+	echo "# You can use this file to keyword/unkeyword the $(pretty_setname ${target}) release." > _HEADER_
+	echo "# Edit Documentation/package.accept_keywords/.${target}/ files instead." >> _HEADER_
+	popd > /dev/null
+	popd > /dev/null
+	popd > /dev/null
+}
+
+# @FUNCTION: get_main_tree_keyword
+# @USAGE: <cp>
+# @DESCRIPTION:
+# Given a <cp>, get the keywords from the highest ebuild version in the gentoo repo.
 get_main_tree_keyword() {
 	local portdir="$(portageq get_repo_path / gentoo)"
 	local cp="${1}"
 
 	echo $(sed -ne 's/^KEYWORDS="\(.*\)"/\1/p' "$(ls ${portdir}/${cp}/*.ebuild | sort | tail -n 1)")
 }
+
+# @FUNCTION: get_package_list_from_set
+# @USAGE: <set name>
+# @DESCRIPTION:
+# Given a <set name>, return all atoms with the version stripped.
+get_package_list_from_set() {
+	local set="${1}"
+
+	for entry in $(grep -v ^[#@] "${SOURCE_REPO}/sets/${set}") ; do
+		echo $(qatom ${entry} | cut -d " " -f 1-2 | tr " " "/")
+	done
+}
+
+# @FUNCTION: mark_unreleased
+# @USAGE: <category-version>
+# @DESCRIPTION:
+# Marks a <category-version> pair as unreleased in kde5.eclass.
+mark_unreleased() {
+	local cv="${1}"
+	sed -i -e "/^KDE_UNRELEASED/s/ )/ ${cv}&/" eclass/kde5.eclass
+}
+
+# @FUNCTION: mask_from_live_set
+# @USAGE: <base set name> <target version> <filename>
+# @DESCRIPTION:
+# Takes sets/<base set name>-live, transforming it a profiles/package.mask/<filename>
+# list of atoms with <target version>.
+mask_from_live_set() {
+	local set="${1}"
+	local version="${2}"
+	local filename="${3}"
+
+	echo "#" >> profiles/package.mask/${filename}
+	echo "# UNRELEASED" >> profiles/package.mask/${filename}
+	echo "#" >> profiles/package.mask/${filename}
+	cat sets/${set}-live >> profiles/package.mask/${filename}
+	sed -i -e "s/9999/${version}/" profiles/package.mask/${filename}
+}
+
+# @FUNCTION: pretty_setname
+# @USAGE: <setname>
+# @DESCRIPTION:
+# Turns a basic set name into a pretty one.
+#
+# For example, "kde-frameworks-5.20" turns into "KDE Frameworks 5.20".
+pretty_setname() {
+	local set="${1}"
+	echo ${set} | tr "-" " " | sed -e "s/\b\(.\)/\u\1/g" -e "s/kde/KDE/i"
+}


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2017-05-11 19:47 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2017-05-11 19:47 UTC (permalink / raw
  To: gentoo-commits

commit:     f65558272f4bb36a9ff25a2310af5afc0608f329
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Thu May 11 19:46:35 2017 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Thu May 11 19:46:56 2017 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=f6555827

Documentation: lib.sh: get_package_list_from_set: Trace sets recursively

 Documentation/maintainers/new/lib.sh | 4 ++++
 1 file changed, 4 insertions(+)

diff --git a/Documentation/maintainers/new/lib.sh b/Documentation/maintainers/new/lib.sh
index 9bd9d1f76c..8da2166e67 100755
--- a/Documentation/maintainers/new/lib.sh
+++ b/Documentation/maintainers/new/lib.sh
@@ -102,6 +102,10 @@ get_package_list_from_set() {
 	for entry in $(grep -v ^[#@] "${SOURCE_REPO}/sets/${set}") ; do
 		echo $(qatom ${entry} | cut -d " " -f 1-2 | tr " " "/")
 	done
+
+	for entry in $(grep ^@ "${SOURCE_REPO}/sets/${set}") ; do
+		get_package_list_from_set ${entry/@/}
+	done
 }
 
 # @FUNCTION: mark_unreleased


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2020-06-22 18:21 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2020-06-22 18:21 UTC (permalink / raw
  To: gentoo-commits

commit:     68d7f27ddf8b60498e155dc6801bf6b2449a9c06
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Mon Jun 22 15:28:42 2020 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Mon Jun 22 15:28:42 2020 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=68d7f27d

Documentation: maintainers: Fix last remnants of kde5.eclass

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/lib.sh | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/Documentation/maintainers/new/copy-to-main-tree.sh b/Documentation/maintainers/new/copy-to-main-tree.sh
index f4d7a87dad..828cdb3349 100755
--- a/Documentation/maintainers/new/copy-to-main-tree.sh
+++ b/Documentation/maintainers/new/copy-to-main-tree.sh
@@ -5,6 +5,7 @@
 # Optional:
 # dev-vcs/git
 # app-portage/mgorny-dev-scripts
+# dev-util/pkgcheck
 
 . $(dirname "$0")/lib.sh
 
@@ -71,4 +72,10 @@ if [[ -d "${TARGET_REPO}/.git" ]] && hash git 2>/dev/null && hash pkgcommit 2>/d
 
 		popd > /dev/null
 	done
+
+	if hash pkgcheck 2>/dev/null; then
+		pushd "${TARGET_REPO}" > /dev/null
+			pkgcheck scan --commits
+		popd > /dev/null
+	fi
 fi


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2020-06-22 18:21 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2020-06-22 18:21 UTC (permalink / raw
  To: gentoo-commits

commit:     6081e79e5b9df5bf8b0d2bdbe5305cbe05c7ba48
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Mon Jun 22 17:16:03 2020 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Mon Jun 22 18:01:31 2020 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=6081e79e

Documentation: copy-to-main-tree.sh: Commit using pkgcommit

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/copy-to-main-tree.sh | 22 +++++++++++++++++++---
 1 file changed, 19 insertions(+), 3 deletions(-)

diff --git a/Documentation/maintainers/new/copy-to-main-tree.sh b/Documentation/maintainers/new/copy-to-main-tree.sh
index da57010723..f4d7a87dad 100755
--- a/Documentation/maintainers/new/copy-to-main-tree.sh
+++ b/Documentation/maintainers/new/copy-to-main-tree.sh
@@ -1,6 +1,10 @@
 #!/bin/bash
 
-# Requires app-portage/repoman
+# Requires:
+# app-portage/repoman
+# Optional:
+# dev-vcs/git
+# app-portage/mgorny-dev-scripts
 
 . $(dirname "$0")/lib.sh
 
@@ -11,12 +15,13 @@ help() {
 	echo Simple set-based ebuild copier.
 	echo
 	echo Given a set in the source repository, copies all ebuilds with the specified
-	echo version into the target repository.
+	echo version into the target repository. Optionally, if target is a git repository,
+	echo each ebuild will be committed as \"cat/pn: TARGETVERSION version bump\"
 	echo
 	echo Reads TARGET_REPO from your enviroment, defaulting to the current directory.
 	echo
 	echo Usage: copy-to-main-tree.sh SETNAME TARGETVERSION
-	echo Example: copy-to-main-tree.sh kde-frameworks-5.15 5.15.0
+	echo Example: copy-to-main-tree.sh kde-frameworks-5.72 5.72.0
 	exit 0
 }
 
@@ -56,3 +61,14 @@ for cp in ${packages} ; do
 	popd > /dev/null
 
 done
+
+if [[ -d "${TARGET_REPO}/.git" ]] && hash git 2>/dev/null && hash pkgcommit 2>/dev/null; then
+	for cp in ${packages} ; do
+		pushd "${TARGET_REPO}/${cp}" > /dev/null
+
+		git add .
+		pkgcommit -sS . -m "${TARGETVERSION} version bump"
+
+		popd > /dev/null
+	done
+fi


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2020-06-22 18:21 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2020-06-22 18:21 UTC (permalink / raw
  To: gentoo-commits

commit:     4edc25c9282a9a6e264f1ffb3c9325d2cae20128
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Mon Jun 22 16:36:29 2020 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Mon Jun 22 18:01:30 2020 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=4edc25c9

Documentation: set-based-remove.sh: Commit using pkgcommit

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/set-based-remove.sh | 21 +++++++++++++++++++--
 1 file changed, 19 insertions(+), 2 deletions(-)

diff --git a/Documentation/maintainers/new/set-based-remove.sh b/Documentation/maintainers/new/set-based-remove.sh
index 8922b7c3b8..3be839d566 100755
--- a/Documentation/maintainers/new/set-based-remove.sh
+++ b/Documentation/maintainers/new/set-based-remove.sh
@@ -1,6 +1,10 @@
 #!/bin/sh
 
-# Requires app-portage/repoman
+# Requires:
+# app-portage/repoman
+# Optional:
+# dev-vcs/git
+# app-portage/mgorny-dev-scripts
 
 . $(dirname "$0")/lib.sh
 
@@ -10,11 +14,13 @@ help() {
 	echo Simple set-based version removed.
 	echo
 	echo Given a set file, removes all packages of a specified version.
+	echo Optionally, if target is a git repository, each change will be
+	echo committed as \"cat/pn: drop VERSION*\".
 	echo
 	echo Reads TARGET_REPO from your environment, defaulting to the current directory.
 	echo
 	echo Usage: set-based-remove.sh SETNAME VERSION
-	echo Example: set-based-remove.sh kde-plasma-5.0 5.0.1
+	echo Example: set-based-remove.sh kde-plasma-5.19 5.19.1
 	exit 0
 }
 
@@ -46,3 +52,14 @@ for package in ${packages} ; do
 	repoman manifest
 	popd > /dev/null
 done
+
+if [[ -d "${TARGET_REPO}/.git" ]] && hash git 2>/dev/null && hash pkgcommit 2>/dev/null; then
+	for cp in ${packages} ; do
+		pushd "${TARGET_REPO}/${cp}" > /dev/null
+
+		git add .
+		pkgcommit -sS . -m "drop ${VERSION}*"
+
+		popd > /dev/null
+	done
+fi


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2020-06-22 18:21 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2020-06-22 18:21 UTC (permalink / raw
  To: gentoo-commits

commit:     6e70d834274b87c7a9338ddc14922ff9049531ee
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Mon Jun 22 16:53:05 2020 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Mon Jun 22 18:01:31 2020 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=6e70d834

Documentation: set-based-remove.sh: Add pkgcheck support

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/set-based-remove.sh | 7 +++++++
 1 file changed, 7 insertions(+)

diff --git a/Documentation/maintainers/new/set-based-remove.sh b/Documentation/maintainers/new/set-based-remove.sh
index 3be839d566..ff4bd8f0f3 100755
--- a/Documentation/maintainers/new/set-based-remove.sh
+++ b/Documentation/maintainers/new/set-based-remove.sh
@@ -5,6 +5,7 @@
 # Optional:
 # dev-vcs/git
 # app-portage/mgorny-dev-scripts
+# dev-util/pkgcheck
 
 . $(dirname "$0")/lib.sh
 
@@ -62,4 +63,10 @@ if [[ -d "${TARGET_REPO}/.git" ]] && hash git 2>/dev/null && hash pkgcommit 2>/d
 
 		popd > /dev/null
 	done
+
+	if hash pkgcheck 2>/dev/null; then
+		pushd "${TARGET_REPO}" > /dev/null
+			pkgcheck scan --commits
+		popd > /dev/null
+	fi
 fi


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2021-03-04 10:29 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2021-03-04 10:29 UTC (permalink / raw
  To: gentoo-commits

commit:     aae58afb6392c5ee77cb3b6d4d2c8c236007f2a2
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Thu Mar  4 09:40:36 2021 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Thu Mar  4 09:43:30 2021 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=aae58afb

Documentation: lib.sh: Drop keywords to testing in bump_packages_from_set()

get_main_tree_keyword() gets us all KEYWORDS, be they arch or ~arch.

Forward-port from f8c30a0be3ae8ea200ac46c0f7c85571b328d72f.

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/lib.sh | 1 +
 1 file changed, 1 insertion(+)

diff --git a/Documentation/maintainers/new/lib.sh b/Documentation/maintainers/new/lib.sh
index b512921c04..a42bea2e00 100755
--- a/Documentation/maintainers/new/lib.sh
+++ b/Documentation/maintainers/new/lib.sh
@@ -39,6 +39,7 @@ bump_packages_from_set() {
 
 		if [[ ${destination} != *9999* ]] ; then
 			ekeyword $(get_main_tree_keyword ${cp}) ${destination} > /dev/null
+			ekeyword ~all ${destination} > /dev/null
 		fi
 
 		repoman manifest


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2021-10-31  3:18 Sam James
  0 siblings, 0 replies; 13+ messages in thread
From: Sam James @ 2021-10-31  3:18 UTC (permalink / raw
  To: gentoo-commits

commit:     f184bf9ffdf5d3cb81711ca483eaf6f2fff81859
Author:     Sam James <sam <AT> gentoo <DOT> org>
AuthorDate: Sun Oct 31 03:18:17 2021 +0000
Commit:     Sam James <sam <AT> gentoo <DOT> org>
CommitDate: Sun Oct 31 03:18:17 2021 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=f184bf9f

Documentation: update scripts to use correct shebang (/bin/bash)

Uses bashisms.

Signed-off-by: Sam James <sam <AT> gentoo.org>

 Documentation/maintainers/new/frameworks-bump.sh  | 2 +-
 Documentation/maintainers/new/set-based-remove.sh | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/Documentation/maintainers/new/frameworks-bump.sh b/Documentation/maintainers/new/frameworks-bump.sh
index 2039c39f4c..7e7ce8b063 100755
--- a/Documentation/maintainers/new/frameworks-bump.sh
+++ b/Documentation/maintainers/new/frameworks-bump.sh
@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 . "$(dirname "$0")/lib.sh"
 
 : ${TARGET_REPO:="$(pwd)"}

diff --git a/Documentation/maintainers/new/set-based-remove.sh b/Documentation/maintainers/new/set-based-remove.sh
index ff4bd8f0f3..2039a589ef 100755
--- a/Documentation/maintainers/new/set-based-remove.sh
+++ b/Documentation/maintainers/new/set-based-remove.sh
@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 
 # Requires:
 # app-portage/repoman


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2022-12-11 21:24 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2022-12-11 21:24 UTC (permalink / raw
  To: gentoo-commits

commit:     5d98c8a316063d3c5839986e39dae1d2114a733e
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Sun Dec 11 14:33:18 2022 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Sun Dec 11 21:24:24 2022 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=5d98c8a3

Documentation: frameworks-bump.sh: Adapt to KF5/KF6 changes

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/frameworks-bump.sh | 28 ++++++++++++++----------
 1 file changed, 17 insertions(+), 11 deletions(-)

diff --git a/Documentation/maintainers/new/frameworks-bump.sh b/Documentation/maintainers/new/frameworks-bump.sh
index 243f46d61e..16706dcf05 100755
--- a/Documentation/maintainers/new/frameworks-bump.sh
+++ b/Documentation/maintainers/new/frameworks-bump.sh
@@ -4,9 +4,9 @@
 : ${TARGET_REPO:="$(pwd)"}
 
 help() {
-	echo "Perform a version bump of KDE Frameworks."
+	echo "Perform a version bump of KDE Frameworks 5 or 6."
 	echo
-	echo "Based on the kde-frameworks-live set, this script performs a full version bump"
+	echo "Based on the kde-frameworks-(5|6)-live set, this script performs a full version bump"
 	echo "of a new unreleased KDE Frameworks."
 	echo
 	echo "In addition to the new ebuild being created, the following operations are performed:"
@@ -17,7 +17,7 @@ help() {
 	echo "* Generation of package.* files in Documentation"
 	echo
 	echo "Usage: frameworks-bump.sh <version>"
-	echo "Example: frameworks-bump.sh 5.30"
+	echo "Example: frameworks-bump.sh 5.101.0"
 	exit 0
 }
 
@@ -33,21 +33,27 @@ if [[ -z "${VERSION}" ]] ; then
 	help
 fi
 
-major_version=$(echo ${VERSION} | cut -d "." -f 1-2)
-kfv="kde-frameworks-${VERSION}"
-kfmv="kde-frameworks-${major_version}"
+major_version=$(echo ${VERSION} | cut -d "." -f 1)
+major_minor_version=$(echo ${VERSION} | cut -d "." -f 1-2)
+kfmv="kde-frameworks-${major_version}-${major_minor_version}"
+setname="kde-frameworks-${major_version}"
+if [[ ${major_version} == 5 ]]; then
+	base_version=5.9999
+else
+	base_version=9999
+fi
 
 pushd "${TARGET_REPO}" > /dev/null
 
-bump_set_from_live kde-frameworks ${major_version}
-mask_from_live_set kde-frameworks ${VERSION} ${kfv}
+bump_set_from_live ${setname} ${major_minor_version}
+mask_from_live_set ${setname} ${VERSION} kde-frameworks-${VERSION}
 mark_unreleased frameworks ${VERSION}
-create_keywords_files ${kfmv} ${set}
+create_keywords_files ${kfmv} ${setname}
 
-sed -i -e "/KF_RELEASES/s/\"$/ ${major_version}\"/" Documentation/maintainers/regenerate-files
+sed -i -e "/KF${major_version}_RELEASES/s/\"$/ ${major_minor_version}\"/" Documentation/maintainers/regenerate-files
 Documentation/maintainers/regenerate-files
 
-bump_packages_from_set kde-frameworks-live 9999 ${VERSION}
+bump_packages_from_set ${setname}-live ${base_version} ${VERSION}
 commit_packages ${kfmv} "${VERSION} version bump"
 
 popd > /dev/null


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2022-12-11 21:24 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2022-12-11 21:24 UTC (permalink / raw
  To: gentoo-commits

commit:     6ef20dc0d29303c86b5deb134dfeaeb8654eb040
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Sun Dec 11 16:42:58 2022 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Sun Dec 11 21:24:24 2022 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=6ef20dc0

Documentation: lib.sh: create_keywords_files: Drop base name hack

Requires providing second argument.

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/frameworks-bump.sh |  2 +-
 Documentation/maintainers/new/gear-bump.sh       |  2 +-
 Documentation/maintainers/new/lib.sh             | 10 +++++-----
 Documentation/maintainers/new/plasma-bump.sh     |  2 +-
 4 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/Documentation/maintainers/new/frameworks-bump.sh b/Documentation/maintainers/new/frameworks-bump.sh
index 1d51c345f5..243f46d61e 100755
--- a/Documentation/maintainers/new/frameworks-bump.sh
+++ b/Documentation/maintainers/new/frameworks-bump.sh
@@ -42,7 +42,7 @@ pushd "${TARGET_REPO}" > /dev/null
 bump_set_from_live kde-frameworks ${major_version}
 mask_from_live_set kde-frameworks ${VERSION} ${kfv}
 mark_unreleased frameworks ${VERSION}
-create_keywords_files ${kfmv}
+create_keywords_files ${kfmv} ${set}
 
 sed -i -e "/KF_RELEASES/s/\"$/ ${major_version}\"/" Documentation/maintainers/regenerate-files
 Documentation/maintainers/regenerate-files

diff --git a/Documentation/maintainers/new/gear-bump.sh b/Documentation/maintainers/new/gear-bump.sh
index 853c1927e6..4d4fc7067e 100755
--- a/Documentation/maintainers/new/gear-bump.sh
+++ b/Documentation/maintainers/new/gear-bump.sh
@@ -42,7 +42,7 @@ pushd "${TARGET_REPO}" > /dev/null
 
 if ! [[ -f sets/kde-gear-${major_version} ]]; then
 	bump_set_from_live kde-gear ${major_version}
-	create_keywords_files ${kfmv}
+	create_keywords_files ${kfmv} kde-gear
 
 	sed -i -e "/GEAR_RELEASES/s/\"$/ ${major_version}\"/" Documentation/maintainers/regenerate-files
 	Documentation/maintainers/regenerate-files

diff --git a/Documentation/maintainers/new/lib.sh b/Documentation/maintainers/new/lib.sh
index d6317e1fa3..59bdcef983 100755
--- a/Documentation/maintainers/new/lib.sh
+++ b/Documentation/maintainers/new/lib.sh
@@ -101,16 +101,16 @@ commit_packages() {
 }
 
 # @FUNCTION: create_keywords_files
-# @USAGE: <set name>
+# @USAGE: <target set> <base setname>
 # @DESCRIPTION:
-# Creates new package.{accept_keywords,unmask,mask}/<set name> files based on
-# live dirs and referencing <set name> including any subsets.
+# Creates new package.{accept_keywords,unmask,mask}/<target set> files based on
+# <base setname>-live dirs and referencing <target setname> including any subsets.
 create_keywords_files() {
 	local target="${1}"
-	local base=${target/%-[0-9.]*/}
+	local base="${2}"
 	local x
 
-	if [[ $# -gt 1 ]]; then
+	if [[ $# -gt 2 ]]; then
 		echo "${FUNCNAME[0]}: error: must be passed exactly one argument!"
 		return
 	fi

diff --git a/Documentation/maintainers/new/plasma-bump.sh b/Documentation/maintainers/new/plasma-bump.sh
index e567fe8763..978f9cc857 100755
--- a/Documentation/maintainers/new/plasma-bump.sh
+++ b/Documentation/maintainers/new/plasma-bump.sh
@@ -42,7 +42,7 @@ pushd "${TARGET_REPO}" > /dev/null
 
 if ! [[ -f sets/kde-plasma-${major_version} ]]; then
 	bump_set_from_live kde-plasma ${major_version} # TODO: s/49.9999/50:5/
-	create_keywords_files ${kfmv}
+	create_keywords_files ${kfmv} kde-plasma
 
 	sed -i -e "/PLASMA_RELEASES/s/\"$/ ${major_version}\"/" Documentation/maintainers/regenerate-files
 	Documentation/maintainers/regenerate-files


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2022-12-11 21:24 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2022-12-11 21:24 UTC (permalink / raw
  To: gentoo-commits

commit:     98c6e0b94ab1696259da040e571a79fd272d5b4f
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Sun Dec 11 15:35:23 2022 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Sun Dec 11 21:24:18 2022 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=98c6e0b9

Documentation: lib.sh: bump_set_from_live: sed *any* version numbers

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/lib.sh | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/Documentation/maintainers/new/lib.sh b/Documentation/maintainers/new/lib.sh
index 26b4b36fe8..d6317e1fa3 100755
--- a/Documentation/maintainers/new/lib.sh
+++ b/Documentation/maintainers/new/lib.sh
@@ -60,7 +60,7 @@ bump_set_from_live() {
 	local destination="${2}"
 
 	cp sets/${target}-live sets/${target}-${destination}
-	sed -i -e "s/~/</" -e "s/9999/${destination}.50/" sets/${target}-${destination}
+	sed -i -E "s/~/</;s/[0-9]+(\.[0-9]+)*$/${destination}.50/" sets/${target}-${destination}
 	sed -i -e "/^@/s/live$/${destination}/" sets/${target}-${destination}
 
 	for entry in $(grep ^@ sets/${target}-live) ; do


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2023-12-17  9:20 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2023-12-17  9:20 UTC (permalink / raw
  To: gentoo-commits

commit:     d95b69ec1905b95bb9d34d82a4b33c1250a082c1
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Sun Dec 17 08:45:59 2023 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Sun Dec 17 09:09:19 2023 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=d95b69ec

Documentation: frameworks-bump.sh: Support KF6 unstable releases

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/frameworks-bump.sh | 11 ++++++++---
 1 file changed, 8 insertions(+), 3 deletions(-)

diff --git a/Documentation/maintainers/new/frameworks-bump.sh b/Documentation/maintainers/new/frameworks-bump.sh
index 9180a1a5c9..84b2813b49 100755
--- a/Documentation/maintainers/new/frameworks-bump.sh
+++ b/Documentation/maintainers/new/frameworks-bump.sh
@@ -6,7 +6,7 @@
 help() {
 	echo "Perform a version bump of KDE Frameworks 5 or 6."
 	echo
-	echo "Based on the kde-frameworks-(5|6)-live set, this script performs a full version bump"
+	echo "Based on the kde-frameworks-(5-)live sets, this script performs a full version bump"
 	echo "of a new unreleased KDE Frameworks."
 	echo
 	echo "In addition to the new ebuild being created, the following operations are performed:"
@@ -34,12 +34,17 @@ if [[ -z "${VERSION}" ]] ; then
 fi
 
 major_version=$(echo ${VERSION} | cut -d "." -f 1)
+if [[ ${VERSION} == 5.2[4-9]?.? ]]; then
+	major_version=6
+fi
 major_minor_version=$(echo ${VERSION} | cut -d "." -f 1-2)
-kfmv="kde-frameworks-${major_version}-${major_minor_version}"
-setname="kde-frameworks-${major_version}"
 if [[ ${major_version} == 5 ]]; then
+	kfmv="kde-frameworks-${major_version}-${major_minor_version}"
 	base_version=5.239.9999
+	setname="kde-frameworks-${major_version}"
 else
+	kfmv="kde-frameworks-${major_minor_version}"
+	setname="kde-frameworks"
 	base_version=9999
 fi
 


^ permalink raw reply related	[flat|nested] 13+ messages in thread

end of thread, other threads:[~2023-12-17  9:20 UTC | newest]

Thread overview: 13+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2020-06-22 18:21 [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/ Andreas Sturmlechner
  -- strict thread matches above, loose matches on Subject: below --
2023-12-17  9:20 Andreas Sturmlechner
2022-12-11 21:24 Andreas Sturmlechner
2022-12-11 21:24 Andreas Sturmlechner
2022-12-11 21:24 Andreas Sturmlechner
2021-10-31  3:18 Sam James
2021-03-04 10:29 Andreas Sturmlechner
2020-06-22 18:21 Andreas Sturmlechner
2020-06-22 18:21 Andreas Sturmlechner
2020-06-22 18:21 Andreas Sturmlechner
2020-06-22 18:21 Andreas Sturmlechner
2017-05-11 19:47 Andreas Sturmlechner
2016-04-15 15:52 Michael Palimaka

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/Documentation/maintainers/new/lib.sh b/Documentation/maintainers/new/lib.sh
index 8da2166e67..abafaf6c4b 100755
--- a/Documentation/maintainers/new/lib.sh
+++ b/Documentation/maintainers/new/lib.sh
@@ -33,7 +33,7 @@ bump_packages_from_set() {
 
 		repoman manifest
 
-        	popd > /dev/null
+		popd > /dev/null
 	done
 }
 
@@ -111,10 +111,10 @@ get_package_list_from_set() {
 # @FUNCTION: mark_unreleased
 # @USAGE: <category-version>
 # @DESCRIPTION:
 # Marks a <category-version> pair as unreleased in kde5.eclass.
 mark_unreleased() {
 	local cv="${1}"
-	sed -i -e "/^KDE_UNRELEASED/s/ )/ ${cv}&/" eclass/kde5.eclass
+	sed -i -e "/^KDE_UNRELEASED/s/ )/ ${cv}&/" eclass/kde.org.eclass
 }
 
 # @FUNCTION: mask_from_live_set


^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [gentoo-commits] proj/kde:master commit in: Documentation/maintainers/new/
@ 2020-06-22 18:21 Andreas Sturmlechner
  0 siblings, 0 replies; 13+ messages in thread
From: Andreas Sturmlechner @ 2020-06-22 18:21 UTC (permalink / raw
  To: gentoo-commits
@@ -111,10 +111,10 @@ get_package_list_from_set() {
 # @USAGE: <category-version>
 # @DESCRIPTION:
-# Marks a <category-version> pair as unreleased in kde5.eclass.
+# Marks a <category-version> pair as unreleased in kde.org.eclass.
 mark_unreleased() {
 	local cv="${1}"

commit:     cef1cb00fb172681ef161c78e3728d1b11cf93cc
Author:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
AuthorDate: Mon Jun 22 17:16:51 2020 +0000
Commit:     Andreas Sturmlechner <asturm <AT> gentoo <DOT> org>
CommitDate: Mon Jun 22 18:01:31 2020 +0000
URL:        https://gitweb.gentoo.org/proj/kde.git/commit/?id=cef1cb00

Documentation: copy-to-main-tree.sh: Add pkgcheck support

Signed-off-by: Andreas Sturmlechner <asturm <AT> gentoo.org>

 Documentation/maintainers/new/copy-to-main-tree.sh | 7 +++++++
 1 file changed, 7 insertions(+)
